==> 0.0.20.tar.gz: lib/widgets/src/chart_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

class UpDownChartFlag extends StatelessWidget {
  const UpDownChartFlag({Key? key, required this.title, required this.money, this.rigntIcon = false, this.onTap}) : super(key: key);

  final String title;
  final String money;
  final bool rigntIcon;
  final GestureTapCallback? onTap;

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: BoxConstraints.tightFor(width: 155.w, height: 75.h),
      padding: EdgeInsets.all(12.r),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(4.r),
        color: const Color(0xffF7F8FA),
      ),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(title, style: TextStyle(color: const Color(0xff646566), fontSize: 13.sp)),
              Visibility(
                visible: rigntIcon,
                child: InkWell(
                  onTap: onTap,
                  child: Padding(
                    padding: EdgeInsets.only(left: 2.w),
                    child: Image(image: ImageUtils.getAssetImage("assets/common/images/doubt.png"), width: 10.5.w, height: 10.5.h, fit: BoxFit.fill),
                  ),
                ),
              )
            ],
          ),
          SizedBox(height: 8.h),
          Text(money, style: TextStyle(color: const Color(0xff323233), fontSize: 20.sp, fontFamily: 'dinFont', fontWeight: FontWeight.w500)),
        ],
      ),
    );
  }
}

==> 0.0.26.tar.gz: lib/widgets/src/chart_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

class UpDownChartFlag extends StatelessWidget {
  const UpDownChartFlag({Key? key, required this.title, required this.money, this.rigntIcon = false, this.onTap, this.fontFamily = "dinFont"}) : super(key: key);

  final String title;
  final String money;
  final bool rigntIcon;
  final GestureTapCallback? onTap;
  final String fontFamily;

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: BoxConstraints.tightFor(width: 155.w, height: 75.h),
      padding: EdgeInsets.all(12.r),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(4.r),
        color: const Color(0xffF7F8FA),
      ),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(title, style: TextStyle(color: const Color(0xff646566), fontSize: 13.sp)),
              Visibility(
                visible: rigntIcon,
                child: InkWell(
                  onTap: onTap,
                  child: Padding(
                    padding: EdgeInsets.only(left: 2.w),
                    child: Image(image: ImageUtils.getAssetImage("assets/images/doubt.png", package: "tengits_common"), width: 10.5.w, height: 10.5.h, fit: BoxFit.fill),
                  ),
                ),
              )
            ],
          ),
          SizedBox(height: 8.h),
          Text(money, style: TextStyle(color: const Color(0xff323233), fontSize: 20.sp, fontFamily: fontFamily, fontWeight: FontWeight.w500)),
        ],
      ),
    );
  }
}
